==> fengoffice_1.7.5.zip: fengoffice/language/en_us/actions.php <==
<?php

  // Actions
  return array(
  
    // Registration
    'register' => 'Register',
    'login' => 'Login',
    'logout' => 'Logout',
    'hide welcome info' => '&raquo; Hide this info permanently',
    
    // Companies
    'add company' => 'Add company',
    'edit company' => 'Edit company info',
    'delete company' => 'Delete company',
    'edit company logo' => 'Update logo',
    'delete company logo' => 'Delete logo',
    
    // Clients
    'add client' => 'Add client',
    'edit client' => 'Edit client',
    'delete client' => 'Delete client',
    
    // Persons
    'add user' => 'Add user',
	'add user role' => 'Role',  
  	'add user action' => 'Add a person to use your Feng Office',
  	'add user button' => 'Add Person',
  	'add user hide settings' => 'Hide all user settings',
  	'add user show settings' => 'See all user settings',
    'add user show settings text' => 'As this person will be using your Feng Office, you may want to set specific details like access permissions<br /> (restricted by default), timezone, password, billing category, etc.',  
  	'add user essential' => 'Essential Information',
  	'add user essential text' => 'This is the only mandatory information on this form. After you click "Add person"<br /> the e-mail address will receive an invitation to join your Feng Office.',
	'add user what does' => 'What this people does',
	'add user what does text' => 'You tell a lot about a person by setting the Role and at which Company.<br />When you select a user Role you define how the person will basically use your Feng Office.',
	'add user others' => 'Access and Other Settings',
	'add user others text' => 'Set what projects will this person be able to access. Set passwords, language, timezone, and other system configuration options.',
    'edit user' => 'Edit user',
    'delete user' => 'Delete user',
    'create user from contact' => 'Create user from contact',
    
    // Group
    'add group' => 'Add group',
    'edit group' => 'Edit group',
    'delete group' => 'Delete group',
    
    // Project
    'add project' => 'Add workspace',
    'edit project' => 'Edit workspace details',
    'delete project' => 'Delete workspace',
    'mark project as finished' => 'Mark workspace as closed',
    'mark project as active' => 'Mark workspace as active',
    
    // Workspace
    'add workspace' => 'Add New Workspace',
    'edit workspace' => 'Edit Workspace',
    'delete workspace' => 'Delete workspace',
    'mark workspace as finished' => 'Mark Workspace as finished',
    'mark workspace as active' => 'Mark Workspace as active',
    
    // Messages
    'add message' => 'Add note',
    'add new message' => 'Add new note',
    'edit message' => 'Edit note',
    'delete message' => 'Delete note',
    'view message' => 'View note',
    'update message options' => 'Update options',
    'subscribe to object' => 'Subscribe',
    'unsubscribe from object' => 'Unsubscribe',
    
    // Comments
    'add comment' => 'Post comment',
    'edit comment' => 'Edit comment',
    
    // Task list
    'add task list' => 'Add task',
    'edit task list' => 'Edit task',
    'delete task list' => 'Delete task',
    'reorder tasks' => 'Reorder tasks',
	'reorder sub tasks' => 'Reorder sub tasks',
  	'copy task' => 'Create a copy of this task',
  	'copy milestone' => 'Create a copy of this milestone',
    
    // Task
    'add task' => 'Add task',
	'add sub task' => 'Add sub task',
    'edit task' => 'Edit task',
    'delete task' => 'Delete task',
    'mark task as completed' => 'Mark task as completed',
    'mark task as open' => 'Mark task as open',
    'apply milestone to subtasks' => 'Apply Milestone to Subtasks',
  	'apply workspace to subtasks' => 'Apply Workspace to Subtasks',
  	  
    // Milestone
    'add milestone' => 'Add milestone',
    'edit milestone' => 'Edit milestone',
    'delete milestone' => 'Delete milestone',
    
    // Events
    'add event' => 'Add event',
    'edit event' => 'Edit event',
    'delete event' => 'Delete event',
    'previous month' => 'Previous month',
    'next month' => 'Next month',
    'previous week' => 'Previous week',
    'next week' => 'Next week',
    'previous day' => 'Previous day',
    'next day' => 'Next day',
    'back to calendar' => 'Back to calendar',
    'back to day' => 'Back to day',
    'pick a date' => 'Pick a date',
    'month' => 'Month',
    'week' => 'Week',
    
    //Groups
    'can edit company data' => 'Can edit owner company data',
    'can manage security' => 'Can manage security',
    'can manage workspaces' => 'Can manage workspaces',
    'can manage configuration' => 'Can manage configuration',
    'can manage contacts' => 'Can manage all contacts',
    'group users' => 'Group users',
    
    
    // People
    'update people' => 'Update',
    'remove user from project' => 'Remove from workspace',
    'remove company from project' => 'Remove from workspace',
    
    // Password
    'update profile' => 'Update profile',
    'change password' => 'Change password',
    'update avatar' => 'Update avatar',
    'delete current avatar' => 'Delete current avatar',
    
    // Forms
    'add form' => 'Add form',
    'edit form' => 'Edit form',
    'delete form' => 'Delete form',
    'submit project form' => 'Submit',
    
    // Files
    'add file' => 'Add file',
    'edit file properties' => 'Edit file Properties',
    'upload file' => 'Upload file',
    'create new revision' => 'Create new Revision',

    'add document' => 'Add document',
    'save document' => 'Save document',
    'add spreadsheet' => 'Add spreadsheet',
    'add presentation' => 'Add presentation',
    'document' => 'Document',
    'spreadsheet' => 'Spreadsheet',
    'presentation' => 'Presentation',

    'new' => 'New',
    'upload' => 'Upload',
    'hide' => 'Hide',
	'show' => 'Show',
    'new document' => 'New document',
    'new spreadsheet' => 'New spreadsheet',
    'new presentation' => 'New presentation',

    'slideshow' => 'Slideshow',
    'revisions and comments' =>'Revisions & Comments',
        
    'Save' => 'Save',
    'all elements' => 'All elements',
    'collapse all' => 'Collapse All',
    'expand all' => 'Expand all',

    'properties' => 'Properties',
    'edit file' => 'Edit file',
    'edit document' => 'Edit document',
    'edit spreadsheet' => 'Edit spreadsheet',
    'edit presentation' => 'Edit presentation',

  	'play' => 'Play',
  	'queue' => 'Queue',
  
    'delete file' => 'Delete file',
    
    'add folder' => 'Add folder',
    'edit folder' => 'Edit folder',
    'delete folder' => 'Delete folder',
    
    'edit file revisions' => 'Edit revision',
    'version' => 'ver',
    'last modification' => 'Last modification',
    
    'link object' => 'Link Object',
    'link objects' => 'Link Objects',
    'show all linked objects' => 'Show all ({0})',
  	'link more objects' => 'Link more objects',
    'unlink' => 'Unlink',
    'unlink object' => 'Unlink Object',
    'unlink objects' => 'Unlink Objects',
	'extract' => 'Extract',
  	'add files to zip' => 'Add files to zip',
  	
    // Tags
    'delete tag'  => 'Delete tag',
    
    // Permissions
    'update permissions' => 'Update permissions',
    'edit permissions' => 'Edit permissions',
    'edit permissions explanation'  => 'Check the boxes to grant users access to the recently created workspace.',
  
  	'save as new revision' => 'Save as new revision',
	'save as' => 'Rename',
	'details' => 'Details',
	'view history for' => 'View history for',
	'view history' => 'View History',    
	'edit preferences' => 'Edit preferences',
	'view milestone' => 'View milestone',
  	'custom properties' => 'Custom Properties',
  	'move to trash' => 'Move to trash',
  	'restore from trash' => 'Restore from trash',
  	'delete permanently' => 'Delete permanently',
  	'copy file' => 'Copy this file',
  	'open weblink' => 'Open web link',
  
	'archive' => 'Archive',
 	'unarchive' => 'Unarchive',
  	'confirm archive selected objects' => 'Are you sure you want to archive the selected objects?',
	'confirm archive object' => 'Are you sure you want to archive this object?',
	'confirm unarchive object' => 'Are you sure you want to unarchive this object?',

  	'report as spam' => 'Report as Spam',
	'not spam' => 'Not Spam',
  
  	'mark as unread' => 'Mark as unread',
  ); // array

?>

==> fengoffice_2.0.0.zip: fengoffice/language/en_us/actions.php <==
<?php

  // Actions
  return array(
  
    // Registration
    'register' => 'Register',
    'login' => 'Login',
    'logout' => 'Logout',
    'hide welcome info' => '&raquo; Hide this info permanently',
    
    // Companies
    'add company' => 'Add company',
    'edit company' => 'Edit company info',
    'delete company' => 'Delete company',
    'edit company logo' => 'Update logo',
    'delete company logo' => 'Delete logo',
    
    // Clients
    'add client' => 'Add client',
    'edit client' => 'Edit client',
    'delete client' => 'Delete client',
    
    // Users
    'add user' => 'Add user',
    'edit user' => 'Edit user',
    'delete user' => 'Delete user',
    'create user from contact' => 'Create user from person',
    
    // Group
    'add group' => 'Add group',
    'edit group' => 'Edit group',
    'delete group' => 'Delete group',
    
    // Project
    'add project' => 'Add workspace',
    'edit project' => 'Edit workspace details',
    'delete project' => 'Delete workspace',
    'mark project as finished' => 'Mark workspace as closed',
    'mark project as active' => 'Mark workspace as active',
    
    // Workspace
    'add workspace' => 'Add New Workspace',
    'edit workspace' => 'Edit Workspace',
    'delete workspace' => 'Delete workspace',
    'mark workspace as finished' => 'Mark Workspace as finished',
    'mark workspace as active' => 'Mark Workspace as active',
    
    // Messages
    'add message' => 'Add note',
    'add new message' => 'Add new note',
    'edit message' => 'Edit note',
    'delete message' => 'Delete note',
    'view message' => 'View note',
    'update message options' => 'Update options',
    'subscribe to object' => 'Subscribe',
    'unsubscribe from object' => 'Unsubscribe',
    
    // Comments
    'add comment' => 'Post comment',
    'edit comment' => 'Edit comment',
    
    // Task list
    'add task list' => 'Add task',
    'edit task list' => 'Edit task',
    'delete task list' => 'Delete task',
    'reorder tasks' => 'Reorder tasks',
	'reorder sub tasks' => 'Reorder sub tasks',
  	'copy task' => 'Create a copy of this task',
  	'copy milestone' => 'Create a copy of this milestone',
    
    // Task
    'add task' => 'Add task',
	'add sub task' => 'Add sub task',
    'edit task' => 'Edit task',
    'delete task' => 'Delete task',
    'mark task as completed' => 'Mark task as completed',
    'mark task as open' => 'Mark task as open',
    'apply milestone to subtasks' => 'Apply Milestone to Subtasks',
  	'apply workspace to subtasks' => 'Apply Workspace to Subtasks',
  	  
    // Milestone
    'add milestone' => 'Add milestone',
    'edit milestone' => 'Edit milestone',
    'delete milestone' => 'Delete milestone',
    
    // Events
    'add event' => 'Add event',
    'edit event' => 'Edit event',
    'delete event' => 'Delete event',
    'previous month' => 'Previous month',
    'next month' => 'Next month',
    'previous week' => 'Previous week',
    'next week' => 'Next week',
    'previous day' => 'Previous day',
    'next day' => 'Next day',
    'back to calendar' => 'Back to calendar',
    'back to day' => 'Back to day',
    'pick a date' => 'Pick a date',
    'month' => 'Month',
    'week' => 'Week',
    
    //Groups
    'can edit company data' => 'Can edit owner company data',
    'can manage security' => 'Can manage security',
    'can manage workspaces' => 'Can manage workspaces',
    'can manage configuration' => 'Can manage configuration',
    'can manage contacts' => 'Can manage all people',
    'group users' => 'Group users',
    
    
    // People
    'update people' => 'Update',
    'remove user from project' => 'Remove from workspace',
    'remove company from project' => 'Remove from workspace',
    
    // Password
    'update profile' => 'Update profile',
    'change password' => 'Change password',
    'update avatar' => 'Update avatar',
    'delete current avatar' => 'Delete current avatar',
    
    // Forms
    'add form' => 'Add form',
    'edit form' => 'Edit form',
    'delete form' => 'Delete form',
    'submit project form' => 'Submit',
    
    // Files
    'add file' => 'Add file',
    'edit file properties' => 'Edit file Properties',
    'upload file' => 'Upload file',
    'create new revision' => 'Create new Revision',

    'add document' => 'Add document',
    'save document' => 'Save document',
    'add spreadsheet' => 'Add spreadsheet',
    'add presentation' => 'Add presentation',
    'document' => 'Document',
    'spreadsheet' => 'Spreadsheet',
    'presentation' => 'Presentation',

    'new' => 'New',
    'upload' => 'Upload',
    'hide' => 'Hide',
	'show' => 'Show',
    'new document' => 'New document',
    'new spreadsheet' => 'New spreadsheet',
    'new presentation' => 'New presentation',

    'slideshow' => 'Slideshow',
    'revisions and comments' =>'Revisions & Comments',
        
    'Save' => 'Save',
    'all elements' => 'All elements',
    'collapse all' => 'Collapse All',
    'expand all' => 'Expand all',

    'properties' => 'Properties',
    'edit file' => 'Edit file',
    'edit document' => 'Edit document',
    'edit spreadsheet' => 'Edit spreadsheet',
    'edit presentation' => 'Edit presentation',

  	'play' => 'Play',
  	'queue' => 'Queue',
  
    'delete file' => 'Delete file',
    
    'add folder' => 'Add folder',
    'edit folder' => 'Edit folder',
    'delete folder' => 'Delete folder',
    
    'edit file revisions' => 'Edit revision',
    'version' => 'ver',
    'last modification' => 'Last modification',
    
    'link object' => 'Link Object',
    'link objects' => 'Link Objects',
    'show all linked objects' => 'Show all ({0})',
  	'link more objects' => 'Link more objects',
    'unlink' => 'Unlink',
    'unlink object' => 'Unlink Object',
    'unlink objects' => 'Unlink Objects',
	'extract' => 'Extract',
  	'add files to zip' => 'Add files to zip',
  	
    // Tags
    'delete tag'  => 'Delete tag',
    
    // Permissions
    'update permissions' => 'Update permissions',
    'edit permissions' => 'Edit permissions',
    'edit permissions explanation'  => 'Check the boxes to grant users access to the recently created workspace.',
  
  	'save as new revision' => 'Save as new revision',
	'save as' => 'Rename',
	'details' => 'Details',
	'view history for' => 'View history for',
	'view history' => 'View History',    
	'edit preferences' => 'Edit preferences',
	'view milestone' => 'View milestone',
  	'custom properties' => 'Custom Properties',
  	'move to trash' => 'Move to trash',
  	'restore from trash' => 'Restore from trash',
  	'delete permanently' => 'Delete permanently',
  	'copy file' => 'Copy this file',
  	'open weblink' => 'Open web link',
  
	'archive' => 'Archive',
 	'unarchive' => 'Unarchive',
  	'confirm archive selected objects' => 'Are you sure you want to archive the selected objects?',
	'confirm archive object' => 'Are you sure you want to archive this object?',
	'confirm unarchive object' => 'Are you sure you want to unarchive this object?',

  	'report as spam' => 'Report as Spam',
	'not spam' => 'Not Spam',
  
  	'mark as unread' => 'Mark as unread',
  	'activate' => 'Activate',
  	'disabled' => 'Disabled',
  	
  	'template context' => 'Choose the template\'s location',
  ); // array

?>
